@@ -11,11 +11,11 @@ ActiveRecord pattern.
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use utf8;
 use Encode;
@@ -61,7 +61,7 @@ sub new {
                         $type .= $rel_opts->{type} if $rel_opts_class eq $class;
                     }
 
-                    if ( $type ~~ ['one_to_many', 'one_to_one'] ) {
+                    if ( $type eq 'one_to_many' or $type eq 'one_to_one' ) {
                         my ($pkey, $fkey_val);
                         if ( $rel_class->can('get_primary_key') ) {
                             $pkey = $rel_class->get_primary_key;
@@ -78,7 +78,7 @@ sub new {
                             $fkey_val
                         )->fetch();
                     }
-                    elsif ( $type ~~ ['many_to_one'] ) {
+                    elsif ( $type eq 'many_to_one' ) {
                         unless ( $self->can('get_primary_key') ) {
                             return $rel_class->new();
                         }
@@ -90,13 +90,12 @@ sub new {
 				$self->$pkey,
 			    );
                     }
-                    elsif ( $type ~~ ['many_to_many'] ) {
+                    elsif ( $type eq 'many_to_many' ) {
                         $self->{"relation_instance_$relname"} =
                             $rel_class->_find_many_to_many({
                                 root_class => $class,
                                 m_class    => ( %{ $rel->{class} } )[0],
                                 self       => $self,
-                                #middle_class_name => ( %{ $rel->{class} } )[0],
                             });
                     }
                 }
@@ -131,23 +130,22 @@ sub _find_many_to_many {
     }
 
     my $connected_table_name = $class->get_table_name;
-    my @sql_tokens = (
-        'select',
-        "$connected_table_name\.*",
-        'from',
-        $param->{m_class}->get_table_name,
-        'join',
-        $connected_table_name,
-        'on',
-        $connected_table_name . '.' . $class->get_primary_key,
-        '=',
-        $param->{m_class}->get_table_name . '.' . $class_opts->{key},
-        'where',
-        $root_class_opts->{key},
-        '=',
-        $param->{self}->{ $param->{root_class}->get_primary_key },
-    );
-    my $sql_stm = join q/ /, @sql_tokens;
+    my $sql_stm;
+    $sql_stm .=
+        'select ' .
+        "$connected_table_name\.*" .
+        ' from ' .
+        $param->{m_class}->get_table_name .
+        ' join ' .
+        $connected_table_name .
+        ' on ' .
+        $connected_table_name . '.' . $class->get_primary_key .
+        ' = ' .
+        $param->{m_class}->get_table_name . '.' . $class_opts->{key} .
+        ' where ' .
+        $root_class_opts->{key} .
+        ' = ' .
+        $param->{self}->{ $param->{root_class}->get_primary_key };
 
     my $container_class = $class->new();
     my $resultset = $class->dbh->selectall_arrayref($sql_stm, { Slice => {} });
@@ -395,15 +393,13 @@ sub find {
     my ($class, @param) = @_;
 
     my $self = $class->new();
-    if (scalar @param == 1 && !ref $param[0]) {
-        #my $self = $class->new();
+    if (scalar @param == 1 && ! ref $param[0]) {
         my $resultset = $self->_find_one_by_primary_key($param[0]);
 
         $self->_fill_params($resultset);
         $self->{isin_database} = 1;
     }
     else {
-        ### ... prepare the request
         $self->{prep_request_method} = undef;
         $self->{prep_request_params} = \@param;
 
@@ -424,12 +420,9 @@ sub find {
 sub fetch {
     my ($self, $limit) = @_;
 
-    if (defined $self->{_objects}) {
-        return $self->_get($limit);
-    }
+    return $self->_get($limit) if defined $self->{_objects};
 
     my $resultset = $self->_find_many_by_prepared_statement();
-
     my @bulk_objects;
     if (defined $resultset && ref $resultset eq 'ARRAY' && scalar @$resultset > 0) {
         my $class = ref $self;
@@ -620,7 +613,6 @@ sub _find_one_by_primary_key {
     return unless $self->dbh;
 
     my $table_name = $self->get_table_name;
-    #return unless $self->can('get_primary_key');
 
     my $pkey = $self->get_primary_key;
 
@@ -734,7 +726,7 @@ ActiveRecord::Simple
 
 =head1 VERSION
 
-0.25
+0.31
 
 =head1 DESCRIPTION
 
@@ -869,6 +861,15 @@ just keep this simple schema in youre mind:
 
     $package_instance->[relation key]->[any method from the related class];
 
+=head2 get_all
+
+You can get a whole table as an arrayref of hashref's:
+
+    my $table = Person->get_all();
+
+You also may specify which rows you want to use:
+
+    my $table = Person->get_all(['name']);
 
 =head2 find
 
@@ -1036,60 +1037,6 @@ You can also specify how many objects you want to use:
     my @persons = MyModel::Person->find('id_person != ?', 1)->fetch(2);
     # fetching only 2 objects.
 
-=head1 Private Methods
-
-Most of this methods you can't use directly in your code.
-
-=head2 _fill_params
-
-Fill parameters.
-
-=head2 _find_many_by_condition
-
-One of the "find" methods.
-
-=head2 _find_many_by_params
-
-One of the "find" methods.
-
-=head2 _find_many_by_primary_keys
-
-One of the "find" methods.
-
-=head2 _find_one_by_primary_key
-
-One of the "find" methods.
-
-=head2 get_all
-
-You can get a whole table as a hashref:
-
-    my $table = Person->get_all();
-
-You also may specify which rows you want to use:
-
-    my $table = Person->get_all(['name']);
-
-=head2 _insert
-
-Insert (save).
-
-=head2 _mk_accessors
-
-This method makes accessors.
-
-=head2 _mk_attribute_getter
-
-This method makes attribute getter.
-
-=head2 _quote_string
-
-Quote string.
-
-=head2 _update
-
-Update (save).
-
 =head1 AUTHOR
 
 shootnix, C<< <shootnix at cpan.org> >>
